@@ -161,6 +161,30 @@ def get_tif_list(ops):
             print('** Found %d tifs - converting to binary **'%(len(fsall)))
     return fsall, ops
 
+
+def get_nd2_list(ops):
+    """ make list of nd2 files to process
+    if ops['look_one_level_down'], then all nd2's in all folders + one level down
+    """
+    froot = ops['data_path']
+    fold_list = ops['data_path']
+    fsall = []
+    nfs = 0
+    first_tiffs = []
+    for k,fld in enumerate(fold_list):
+        fs, ftiffs = list_files(fld, ops['look_one_level_down'],
+                                ["*.nd2"])
+        fsall.extend(fs)
+        first_tiffs.extend(list(ftiffs))
+    if len(fs)==0:
+        print('Could not find any nd2 files')
+        raise Exception('no nd2s')
+    else:
+        ops['first_tiffs'] = np.array(first_tiffs).astype('bool')
+        print('** Found %d nd2 files - converting to binary **'%(len(fsall)))
+    return fsall, ops
+
+
 def find_files_open_binaries(ops1, ish5=False):
     """  finds tiffs or h5 files and opens binaries for writing
 
@@ -216,6 +240,11 @@ def find_files_open_binaries(ops1, ish5=False):
         fs, ops2 = get_sbx_list(ops1[0])
         print('Scanbox files:')
         print('\n'.join(fs))
+    elif input_format == 'nd2':
+        # find nd2s
+        fs, ops2 = get_nd2_list(ops1[0])
+        print('Nikon files:')
+        print('\n'.join(fs))
     else:
         # find tiffs
         fs, ops2 = get_tif_list(ops1[0])
