@@ -1,3 +1,3 @@
-from .register import register_binary
+from .register import register_binary, registration_wrapper
 from .metrics import get_pc_metrics
 from .zalign import compute_zpos
